poscarUtils
========================

- The :class:`pyprocar.pyposcar.poscar_modify` class is used for general manipulation of the crystal geometry of an electronic structure calculation.

- The :class:`pyprocar.pyposcar.poscar_supercell` class is used to create a supercell with the given dimension.

- The :meth:`pyprocar.pyposcar.poscarDiff` function is used to compare two POSCAR files or objects.


.. autosummary::
   :toctree: _autosummary

   pyprocar.pyposcar.poscar_modify
   pyprocar.pyposcar.poscar_supercell
   pyprocar.pyposcar.poscarDiff
